@@ -4,7 +4,7 @@ from autoarray import exc
 from autoarray.util import mask_util
 
 
-class Convolver(object):
+class Convolver:
     def __init__(self, mask, kernel):
         """ Class to setup the 1D convolution of an / util matrix.
 
@@ -325,7 +325,7 @@ class Convolver(object):
             blurring_frame_1d_lengths=self.blurring_frame_1d_lengths,
         )
 
-        return self.mask.mapping.array_from_array_1d(array_1d=convolved_image)
+        return self.mask.mapping.array_stored_1d_from_array_1d(array_1d=convolved_image)
 
     @staticmethod
     @decorator_util.jit()
