@@ -5,31 +5,29 @@ import numpy as np
 from test_autoarray.mock import mock_inversion
 
 
-class TestImagingFit:
+class TestFitImaging:
     def test__image_and_model_are_identical__no_masking__check_values_are_correct(self):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
 
-        data = aa.masked_array.manual_1d(
-            array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask
-        )
-        noise_map = aa.masked_array.manual_1d(
+        data = aa.MaskedArray.manual_1d(array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask)
+        noise_map = aa.MaskedArray.manual_1d(
             array=np.array([2.0, 2.0, 2.0, 2.0]), mask=mask
         )
 
-        imaging = aa.imaging(image=data, noise_map=noise_map)
+        imaging = aa.Imaging(image=data, noise_map=noise_map)
 
-        masked_imaging = aa.masked_imaging(imaging=imaging, mask=mask)
+        masked_imaging = aa.MaskedImaging(imaging=imaging, mask=mask)
 
-        model_data = aa.masked_array.manual_1d(
+        model_image = aa.MaskedArray.manual_1d(
             array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask
         )
 
-        fit = aa.fit(masked_dataset=masked_imaging, model_data=model_data)
+        fit = aa.FitImaging(masked_imaging=masked_imaging, model_image=model_image)
 
         assert (fit.mask == np.array([[False, False], [False, False]])).all()
 
@@ -69,26 +67,24 @@ class TestImagingFit:
         self
     ):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array([[False, False], [True, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
 
-        data = aa.masked_array.manual_1d(array=np.array([1.0, 2.0, 4.0]), mask=mask)
-        noise_map = aa.masked_array.manual_1d(
-            array=np.array([2.0, 2.0, 2.0]), mask=mask
-        )
+        data = aa.MaskedArray.manual_1d(array=np.array([1.0, 2.0, 4.0]), mask=mask)
+        noise_map = aa.MaskedArray.manual_1d(array=np.array([2.0, 2.0, 2.0]), mask=mask)
 
-        imaging = aa.imaging(image=data, noise_map=noise_map)
+        imaging = aa.Imaging(image=data, noise_map=noise_map)
 
-        masked_imaging = aa.masked_imaging(imaging=imaging, mask=mask)
+        masked_imaging = aa.MaskedImaging(imaging=imaging, mask=mask)
 
-        model_data = aa.masked_array.manual_1d(
+        model_image = aa.MaskedArray.manual_1d(
             array=np.array([1.0, 2.0, 3.0]), mask=mask
         )
 
-        fit = aa.fit(masked_dataset=masked_imaging, model_data=model_data)
+        fit = aa.FitImaging(masked_imaging=masked_imaging, model_image=model_image)
 
         assert (fit.mask == np.array([[False, False], [True, False]])).all()
 
@@ -126,24 +122,22 @@ class TestImagingFit:
         self
     ):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
 
-        data = aa.masked_array.manual_1d(
-            array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask
-        )
-        noise_map = aa.masked_array.manual_1d(
+        data = aa.MaskedArray.manual_1d(array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask)
+        noise_map = aa.MaskedArray.manual_1d(
             array=np.array([2.0, 2.0, 2.0, 2.0]), mask=mask
         )
 
-        imaging = aa.imaging(image=data, noise_map=noise_map)
+        imaging = aa.Imaging(image=data, noise_map=noise_map)
 
-        masked_imaging = aa.masked_imaging(imaging=imaging, mask=mask)
+        masked_imaging = aa.MaskedImaging(imaging=imaging, mask=mask)
 
-        model_data = aa.masked_array.manual_1d(
+        model_image = aa.MaskedArray.manual_1d(
             array=np.array([1.0, 2.0, 3.0, 4.0]), mask=mask
         )
 
@@ -153,8 +147,8 @@ class TestImagingFit:
             log_det_regularization_matrix_term=4.0,
         )
 
-        fit = aa.fit(
-            masked_dataset=masked_imaging, model_data=model_data, inversion=inversion
+        fit = aa.FitImaging(
+            masked_imaging=masked_imaging, model_image=model_image, inversion=inversion
         )
 
         assert fit.chi_squared == 0.0
@@ -171,35 +165,40 @@ class TestImagingFit:
         assert fit.figure_of_merit == fit.evidence
 
 
-class TestInterferometerFit:
+class TestFitInterferometer:
     def test__visibilities_and_model_are_identical__no_masking__check_values_are_correct(
         self
     ):
 
         visibilities_mask = np.full(fill_value=False, shape=(2, 2))
 
-        real_space_mask = aa.mask.manual(
+        real_space_mask = aa.Mask.manual(
             mask_2d=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
 
-        data = aa.visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
-        noise_map = aa.visibilities.manual_1d(visibilities=[[2.0, 2.0], [2.0, 2.0]])
+        data = aa.Visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
+        noise_map = aa.Visibilities.manual_1d(visibilities=[[2.0, 2.0], [2.0, 2.0]])
 
-        interferometer = aa.interferometer(
+        interferometer = aa.Interferometer(
             visibilities=data, noise_map=noise_map, uv_wavelengths=np.ones(shape=(2, 2))
         )
 
-        masked_interferometer = aa.masked_interferometer(
+        masked_interferometer = aa.MaskedInterferometer(
             interferometer=interferometer,
             visibilities_mask=visibilities_mask,
             real_space_mask=real_space_mask,
         )
 
-        model_data = aa.visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
+        model_visibilities = aa.Visibilities.manual_1d(
+            visibilities=[[1.0, 2.0], [3.0, 4.0]]
+        )
 
-        fit = aa.fit(masked_dataset=masked_interferometer, model_data=model_data)
+        fit = aa.FitInterferometer(
+            masked_interferometer=masked_interferometer,
+            model_visibilities=model_visibilities,
+        )
 
         assert (
             fit.visibilities_mask == np.array([[False, False], [False, False]])
@@ -236,28 +235,33 @@ class TestInterferometerFit:
 
         visibilities_mask = np.full(fill_value=False, shape=(2, 2))
 
-        real_space_mask = aa.mask.manual(
+        real_space_mask = aa.Mask.manual(
             mask_2d=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
 
-        data = aa.visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
-        noise_map = aa.visibilities.manual_1d(visibilities=[[2.0, 2.0], [2.0, 2.0]])
+        data = aa.Visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
+        noise_map = aa.Visibilities.manual_1d(visibilities=[[2.0, 2.0], [2.0, 2.0]])
 
-        interferometer = aa.interferometer(
+        interferometer = aa.Interferometer(
             visibilities=data, noise_map=noise_map, uv_wavelengths=np.ones(shape=(2, 2))
         )
 
-        masked_interferometer = aa.masked_interferometer(
+        masked_interferometer = aa.MaskedInterferometer(
             interferometer=interferometer,
             visibilities_mask=visibilities_mask,
             real_space_mask=real_space_mask,
         )
 
-        model_data = aa.visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 3.0]])
+        model_visibilities = aa.Visibilities.manual_1d(
+            visibilities=[[1.0, 2.0], [3.0, 3.0]]
+        )
 
-        fit = aa.fit(masked_dataset=masked_interferometer, model_data=model_data)
+        fit = aa.FitInterferometer(
+            masked_interferometer=masked_interferometer,
+            model_visibilities=model_visibilities,
+        )
 
         assert (
             fit.visibilities_mask == np.array([[False, False], [False, False]])
@@ -294,26 +298,28 @@ class TestInterferometerFit:
 
         visibilities_mask = np.full(fill_value=False, shape=(2, 2))
 
-        real_space_mask = aa.mask.manual(
+        real_space_mask = aa.Mask.manual(
             mask_2d=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
 
-        data = aa.visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
-        noise_map = aa.visibilities.manual_1d(visibilities=[[2.0, 2.0], [2.0, 2.0]])
+        data = aa.Visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
+        noise_map = aa.Visibilities.manual_1d(visibilities=[[2.0, 2.0], [2.0, 2.0]])
 
-        interferometer = aa.interferometer(
+        interferometer = aa.Interferometer(
             visibilities=data, noise_map=noise_map, uv_wavelengths=np.ones(shape=(2, 2))
         )
 
-        masked_interferometer = aa.masked_interferometer(
+        masked_interferometer = aa.MaskedInterferometer(
             interferometer=interferometer,
             visibilities_mask=visibilities_mask,
             real_space_mask=real_space_mask,
         )
 
-        model_data = aa.visibilities.manual_1d(visibilities=[[1.0, 2.0], [3.0, 4.0]])
+        model_visibilities = aa.Visibilities.manual_1d(
+            visibilities=[[1.0, 2.0], [3.0, 4.0]]
+        )
 
         inversion = mock_inversion.MockFitInversion(
             regularization_term=2.0,
@@ -321,9 +327,9 @@ class TestInterferometerFit:
             log_det_regularization_matrix_term=4.0,
         )
 
-        fit = aa.fit(
-            masked_dataset=masked_interferometer,
-            model_data=model_data,
+        fit = aa.FitInterferometer(
+            masked_interferometer=masked_interferometer,
+            model_visibilities=model_visibilities,
             inversion=inversion,
         )
 
